======
YASPOP
======


.. image:: https://img.shields.io/pypi/v/yaspop.svg
        :target: https://pypi.python.org/pypi/yaspop

.. image:: https://img.shields.io/travis/ismaelharunid/yaspop.svg
        :target: https://travis-ci.com/ismaelharunid/yaspop

.. image:: https://readthedocs.org/projects/yaspop/badge/?version=latest
        :target: https://yaspop.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/ismaelharunid/yaspop/shield.svg
     :target: https://pyup.io/repos/github/ismaelharunid/yaspop/
     :alt: Updates



yaspop is yet another simple python option parser. use it and make pop proud.


* Free software: GNU General Public License v3
* Documentation: https://yaspop.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
